@@ -36,9 +36,9 @@ pub const DONT_RUN_AGAIN: RunAgain = false;
 ///     A compare operator that takes two numbers and outputs the comparisons between them
 /// */
 /// impl Implementation for Compare {
-///     fn run(&self, mut inputs: &Vec<Vec<Value>>) -> (Option<Value>, RunAgain) {
-///         let left = inputs[0][0].as_i64().unwrap();
-///         let right = inputs[1][0].as_i64().unwrap();
+///     fn run(&self, mut inputs: &[Value]) -> (Option<Value>, RunAgain) {
+///         let left = inputs[0].as_i64().unwrap();
+///         let right = inputs[1].as_i64().unwrap();
 ///
 ///         let output = json!({
 ///                     "equal" : left == right,
@@ -51,11 +51,8 @@ pub const DONT_RUN_AGAIN: RunAgain = false;
 ///         (None, RUN_AGAIN)
 ///     }
 /// }
-///
-/// # fn main() {
-/// # }
 /// ```
 pub trait Implementation : RefUnwindSafe + UnwindSafe + Sync + Send + Debug {
     /// The `run` method is used to execute the implementation
-    fn run(&self, inputs: &Vec<Vec<Value>>) -> (Option<Value>, RunAgain);
+    fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain);
 }
\ No newline at end of file
